==> 0.0.1.tar.gz: lib/src/edu_badge_textfield.dart <==
import 'package:flutter/material.dart';

class EduTextfield extends StatelessWidget {
  final double width;
  const EduTextfield({
    this.width = 250,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    final controller = TextEditingController();
    return Container(
      width: width,
      height: 40,
      padding: const EdgeInsets.symmetric(vertical: 12),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(5),
        border: Border.all(
          width: 1,
          color: const Color(0xFFD0D5DD),
        ),
      ),
      child: TextField(
        controller: controller,
        style: const TextStyle(
          fontFamily: "Inter",
          color: Color(0xFF344054),
          fontSize: 16,
          fontWeight: FontWeight.w500,
        ),
        decoration: const InputDecoration(
          border: OutlineInputBorder(
            borderSide: BorderSide.none,
          ),
        ),
      ),
    );
  }
}

class EduBadgeText extends StatelessWidget {
  final String text;
  final bool isRequired;
  const EduBadgeText({
    super.key,
    required this.text,
    this.isRequired = false,
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Text(
          text,
          style: const TextStyle(
            fontFamily: "Inter",
            color: Color(0xFF344054),
            fontSize: 14,
            fontWeight: FontWeight.w500,
          ),
        ),
        const SizedBox(width: 4),
        isRequired
            ? const Text(
          "*",
          style: TextStyle(
            fontFamily: "Inter",
            color: Color(0xFFFF0000),
            fontSize: 14,
            fontWeight: FontWeight.w500,
          ),
        )
            : const SizedBox(),
      ],
    );
  }
}

==> 0.0.2.tar.gz: lib/src/edu_badge_textfield.dart <==
import 'package:flutter/material.dart';

class EduTextfield extends StatelessWidget {
  final double width;
  final String hintText;
  const EduTextfield({
    this.width = 250,
    this.hintText = "",
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    final controller = TextEditingController();
    return Container(
      width: width,
      height: 40,
      padding: const EdgeInsets.only(top: 15),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(5),
        border: Border.all(
          width: 1,
          color: const Color(0xFFD0D5DD),
        ),
      ),
      child: TextField(
        controller: controller,
        style: const TextStyle(
          fontFamily: "Inter",
          color: Color(0xFF344054),
          fontSize: 16,
          fontWeight: FontWeight.w500,
        ),
        decoration: InputDecoration(
          hintText: hintText,
          hintStyle: const TextStyle(
            fontFamily: "Inter",
            fontWeight: FontWeight.w500,
            fontSize: 16,
            color: Color(0xFF667085),
          ),
          border: const OutlineInputBorder(
            borderSide: BorderSide.none,
          ),
        ),
      ),
    );
  }
}

class EduBadgeText extends StatelessWidget {
  final String text;
  final bool isRequired;
  const EduBadgeText({
    super.key,
    required this.text,
    this.isRequired = false,
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Text(
          text,
          style: const TextStyle(
            fontFamily: "Inter",
            color: Color(0xFF344054),
            fontSize: 14,
            fontWeight: FontWeight.w500,
          ),
        ),
        const SizedBox(width: 4),
        isRequired
            ? const Text(
          "*",
          style: TextStyle(
            fontFamily: "Inter",
            color: Color(0xFFFF0000),
            fontSize: 14,
            fontWeight: FontWeight.w500,
          ),
        )
            : const SizedBox(),
      ],
    );
  }
}
